@@ -3,7 +3,6 @@ Module for validating schemas for various types
 """
 import logging
 from jsonschema import Draft7Validator  # type: ignore
-from ._registered_types.schemas import load_resource_as_json
 from .exceptions import SpecException
 
 _log = logging.getLogger(__name__)
@@ -21,11 +20,6 @@ def validate_schema_for_spec(spec_type: str, field_spec: dict, type_schema: dict
     Raises:
         SpecException if validation fails
     """
-    definitions = load_resource_as_json('definitions.json')
-    if 'definitions' in type_schema:
-        type_schema['definitions'].update(definitions['definitions'])
-    else:
-        type_schema['definitions'] = definitions['definitions']
     validator = Draft7Validator(type_schema)
     errors = sorted(validator.iter_errors(field_spec), key=lambda e: e.path)
     if len(errors) > 0:
